MenuDropdownButton class

Inheritance

Constructors

const

Properties

buttonColor Color?
Optional background color of the root button
final
config MenuDropdownConfig
Configuration
final
Optional footer widget
final
hashCode int
The hash code for this object.
no setterinherited
Optional header widget
final
icon Widget?
Optional custom icon widget for the root button (e.g. Icon, HeroIcon, SvgPicture)
final
items List<MenuItem>
Menu items
final
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
label String?
Optional text for the root button
final
labelTextStyle TextStyle?
Optional style for the root text
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
tooltip String
Tooltip shown on hover
final
tooltipBackgroundColor Color?
Optional tooltip background color
final
tooltipTextColor Color?
Optional tooltip text color
final

Methods

createElement() StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() State<MenuDropdownButton>
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited