MenuDropdownConfig class

Constructors

const

Properties

alignment MenuAlignment
final
animationDuration Duration
final
backgroundColor Color
final
borderRadius double
final
contentPadding EdgeInsets
final
Distance between the dropdown and the button
final
elevation double
final
footerTextStyle TextStyle?
final
hashCode int
The hash code for this object.
no setterinherited
headerTextStyle TextStyle?
final
iconSize double
final
itemIconColor Color?
final
labelTextStyle TextStyle?
final
maxHeight double?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
tooltipBackgroundColor Color?
final
tooltipTextColor Color?
final
width double?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited