MenuItem class

Constructors

const

Properties

customWidget Widget?
final
hashCode int
The hash code for this object.
no setterinherited
icon Widget?
final
isDivider bool
final
label String?
final
labelStyle TextStyle?
final
onTap VoidCallback?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
trailing Widget?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited