MenuDropdownConfig class
Constructors
- MenuDropdownConfig({Color backgroundColor = Colors.white, double borderRadius = 6, double elevation = 4, double? width, double? maxHeight, EdgeInsets contentPadding = const EdgeInsets.symmetric(vertical: 8), TextStyle? labelTextStyle = const TextStyle(color: Colors.black, fontSize: 14), Color? itemIconColor, double iconSize = 20, Duration animationDuration = const Duration(milliseconds: 150), MenuAlignment alignment = MenuAlignment.left, double dropdownOffset = 8.0, Color? tooltipTextColor, Color? tooltipBackgroundColor, TextStyle? headerTextStyle, })
-
const
Properties
- alignment → MenuAlignment
-
final
- animationDuration → Duration
-
final
- backgroundColor → Color
-
final
- borderRadius → double
-
final
- contentPadding → EdgeInsets
-
final
- dropdownOffset → double
-
Distance between the dropdown and the button
final
- elevation → double
-
final
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- headerTextStyle → TextStyle?
-
final
- iconSize → double
-
final
- itemIconColor → Color?
-
final
- labelTextStyle → TextStyle?
-
final
- maxHeight → double?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- tooltipBackgroundColor → Color?
-
final
- tooltipTextColor → Color?
-
final
- width → double?
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited